@@ -3,7 +3,7 @@
 import json
 
 
-class Job(object):
+class Job:
     """ Job's Class """
 
     cpt_id = 0
